:orphan:

Introduction
============

Before we start exploring the main components of Ansible -- playbooks, configuration management, deployment, and orchestration -- we'll learn how to get Ansible installed and cover some basic concepts.  We'll also go over how to execute ad-hoc commands in parallel across your nodes using /usr/bin/ansible, and see what modules are available in Ansible's core (you can also write your own, which is covered later).

.. toctree::
   :maxdepth: 1

   ../installation_guide/index
   ../dev_guide/overview_architecture
   ../installation_guide/intro_configuration
   intro_bsd
   intro_windows
